@@ -487,7 +487,8 @@ class AutogenDoc():
             f'autogen_{name}.{self.locale[:2]}.adoc',
         )
         self.filename_tmp = f'{self.filename}.tmp'
-        self._file = open(self.filename_tmp, 'w')
+        # pylint: disable=consider-using-with
+        self._file = open(self.filename_tmp, 'w', encoding='utf-8')
 
     def write_autogen_files(self, weechat_doc):
         """Write auto-generated files."""
@@ -782,7 +783,7 @@ class AutogenDoc():
         self.write('// tag::url_options[]')
         self.write('[width="100%",cols="2,^1,7",options="header"]')
         self.write('|===')
-        self.write('| %s | %s ^(1)^ | %s ^(2)^\n',
+        self.write('| %s | %s ^(1)^ | %s ^(2)^\n',
                    _('Option'), _('Type'), _('Constants'))
         for option in url_options:
             constants = option['constants']
