@@ -35,6 +35,18 @@
 #include "../../plugins/plugin.h"
 
 
+/*
+ * Returns description of hook.
+ *
+ * Note: result must be freed after use.
+ */
+
+char *
+hook_focus_get_description (struct t_hook *hook)
+{
+    return strdup (HOOK_FOCUS(hook, area));
+}
+
 /*
  * Hooks a focus.
  *
