@@ -33,6 +33,18 @@
 #include "../wee-string.h"
 
 
+/*
+ * Returns description of hook.
+ *
+ * Note: result must be freed after use.
+ */
+
+char *
+hook_info_get_description (struct t_hook *hook)
+{
+    return strdup (HOOK_INFO(hook, info_name));
+}
+
 /*
  * Hooks an info.
  *
