@@ -33,6 +33,18 @@
 #include "../wee-string.h"
 
 
+/*
+ * Returns description of hook.
+ *
+ * Note: result must be freed after use.
+ */
+
+char *
+hook_infolist_get_description (struct t_hook *hook)
+{
+    return strdup (HOOK_INFOLIST(hook, infolist_name));
+}
+
 /*
  * Hooks an infolist.
  *
