@@ -46,6 +46,8 @@
 #include "wee-string.h"
 #include "../gui/gui-completion.h"
 #include "../gui/gui-bar.h"
+#include "../gui/gui-bar-item.h"
+#include "../gui/gui-bar-item-custom.h"
 #include "../gui/gui-bar-window.h"
 #include "../gui/gui-buffer.h"
 #include "../gui/gui-color.h"
@@ -60,6 +62,28 @@
 extern char **environ;
 
 
+/*
+ * Adds a word with quotes around to completion list.
+ */
+
+void
+completion_list_add_quoted_word (struct t_gui_completion *completion,
+                                 const char *word)
+{
+    char *temp;
+    int length;
+
+    length = 1 + strlen (word) + 1 + 1;
+    temp = malloc (length);
+    if (!temp)
+        return;
+
+    snprintf (temp, length, "\"%s\"", word);
+    gui_completion_list_add (completion, temp, 0, WEECHAT_LIST_POS_END);
+
+    free (temp);
+}
+
 /*
  * Adds bar names to completion list.
  */
@@ -87,6 +111,152 @@ completion_list_add_bars_names_cb (const void *pointer, void *data,
     return WEECHAT_RC_OK;
 }
 
+/*
+ * Adds custom bar items names to completion list.
+ */
+
+int
+completion_list_add_custom_bar_items_names_cb (const void *pointer, void *data,
+                                               const char *completion_item,
+                                               struct t_gui_buffer *buffer,
+                                               struct t_gui_completion *completion)
+{
+    struct t_gui_bar_item_custom *ptr_item;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) completion_item;
+    (void) buffer;
+
+    for (ptr_item = gui_custom_bar_items; ptr_item;
+         ptr_item = ptr_item->next_item)
+    {
+        gui_completion_list_add (completion, ptr_item->bar_item->name,
+                                 0, WEECHAT_LIST_POS_SORT);
+    }
+
+    return WEECHAT_RC_OK;
+}
+
+/*
+ * Adds custom bar item conditions to completion list.
+ */
+
+int
+completion_list_add_custom_bar_item_conditions_cb (const void *pointer, void *data,
+                                                   const char *completion_item,
+                                                   struct t_gui_buffer *buffer,
+                                                   struct t_gui_completion *completion)
+{
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) completion_item;
+    (void) buffer;
+
+    gui_completion_list_add (completion,
+                             "\"" GUI_BAR_ITEM_CUSTOM_DEFAULT_CONDITIONS "\"",
+                             0,
+                             WEECHAT_LIST_POS_END);
+    gui_completion_list_add (completion, "\"\"", 0, WEECHAT_LIST_POS_END);
+
+    return WEECHAT_RC_OK;
+}
+
+/*
+ * Adds custom bar item contents to completion list.
+ */
+
+int
+completion_list_add_custom_bar_item_contents_cb (const void *pointer, void *data,
+                                                 const char *completion_item,
+                                                 struct t_gui_buffer *buffer,
+                                                 struct t_gui_completion *completion)
+{
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) completion_item;
+    (void) buffer;
+
+    gui_completion_list_add (completion,
+                             "\"" GUI_BAR_ITEM_CUSTOM_DEFAULT_CONTENTS "\"",
+                             0,
+                             WEECHAT_LIST_POS_END);
+    gui_completion_list_add (completion, "\"\"", 0, WEECHAT_LIST_POS_END);
+
+    return WEECHAT_RC_OK;
+}
+
+/*
+ * Adds arguments for commands that add a custom bar item.
+ */
+
+int
+completion_list_add_custom_bar_item_add_arguments_cb (const void *pointer, void *data,
+                                                      const char *completion_item,
+                                                      struct t_gui_buffer *buffer,
+                                                      struct t_gui_completion *completion)
+{
+    char **sargv;
+    int sargc, arg_complete;
+    struct t_gui_bar_item_custom *ptr_item;
+
+    if (!completion->args)
+        return WEECHAT_RC_OK;
+
+    sargv = string_split_shell (completion->args, &sargc);
+    if (!sargv)
+        return WEECHAT_RC_OK;
+
+    ptr_item = (sargc > 1) ? gui_bar_item_custom_search (sargv[1]) : NULL;
+
+    arg_complete = sargc;
+    if (completion->base_word && completion->base_word[0])
+        arg_complete--;
+
+    switch (arg_complete)
+    {
+        case 1:
+            completion_list_add_custom_bar_items_names_cb (pointer, data,
+                                                           completion_item,
+                                                           buffer, completion);
+
+            break;
+        case 2:
+            if (ptr_item)
+            {
+                completion_list_add_quoted_word (
+                    completion,
+                    CONFIG_STRING(ptr_item->options[GUI_BAR_ITEM_CUSTOM_OPTION_CONDITIONS]));
+            }
+            else
+            {
+                completion_list_add_custom_bar_item_conditions_cb (
+                    pointer, data, completion_item, buffer, completion);
+            }
+            break;
+        case 3:
+            if (ptr_item)
+            {
+                completion_list_add_quoted_word (
+                    completion,
+                    CONFIG_STRING(ptr_item->options[GUI_BAR_ITEM_CUSTOM_OPTION_CONTENT]));
+            }
+            else
+            {
+                completion_list_add_custom_bar_item_contents_cb (
+                    pointer, data, completion_item, buffer, completion);
+            }
+            break;
+    }
+
+    string_free_split (sargv);
+
+    return WEECHAT_RC_OK;
+}
+
 /*
  * Adds bar options to completion list.
  */
@@ -1865,6 +2035,19 @@ completion_init ()
     hook_completion (NULL, "bars_names", /* formerly "%r" */
                      N_("names of bars"),
                      &completion_list_add_bars_names_cb, NULL, NULL);
+    hook_completion (NULL, "custom_bar_items_names",
+                     N_("names of custom bar items"),
+                     &completion_list_add_custom_bar_items_names_cb, NULL, NULL);
+    hook_completion (NULL, "custom_bar_item_conditions",
+                     N_("conditions for custom bar item"),
+                     &completion_list_add_custom_bar_item_conditions_cb, NULL, NULL);
+    hook_completion (NULL, "custom_bar_item_contents",
+                     N_("contents for custom bar item"),
+                     &completion_list_add_custom_bar_item_contents_cb, NULL, NULL);
+    hook_completion (NULL, "custom_bar_item_add_arguments",
+                     N_("arguments for command that adds a custom bar item: "
+                        "item name, conditions, content"),
+                     &completion_list_add_custom_bar_item_add_arguments_cb, NULL, NULL);
     hook_completion (NULL, "config_option_values", /* formerly "%v" */
                      N_("values for a configuration option"),
                      &completion_list_add_config_option_values_cb, NULL, NULL);
