@@ -127,6 +127,7 @@ extern struct t_config_file *weechat_config_file;
 extern struct t_config_section *weechat_config_section_color;
 extern struct t_config_section *weechat_config_section_proxy;
 extern struct t_config_section *weechat_config_section_bar;
+extern struct t_config_section *weechat_config_section_custom_bar_item;
 extern struct t_config_section *weechat_config_section_notify;
 
 extern struct t_config_option *config_startup_command_after_plugins;
@@ -172,6 +173,7 @@ extern struct t_config_option *config_look_day_change_message_2dates;
 extern struct t_config_option *config_look_eat_newline_glitch;
 extern struct t_config_option *config_look_emphasized_attributes;
 extern struct t_config_option *config_look_highlight;
+extern struct t_config_option *config_look_highlight_disable_regex;
 extern struct t_config_option *config_look_highlight_regex;
 extern struct t_config_option *config_look_highlight_tags;
 extern struct t_config_option *config_look_hotlist_add_conditions;
@@ -356,6 +358,7 @@ extern int config_length_nick_prefix_suffix;
 extern int config_length_prefix_same_nick;
 extern int config_length_prefix_same_nick_middle;
 extern int config_emphasized_attributes;
+extern regex_t *config_highlight_disable_regex;
 extern regex_t *config_highlight_regex;
 extern char ***config_highlight_tags;
 extern int config_num_highlight_tags;
