@@ -36,7 +36,7 @@ struct t_string_dyn
 
 struct t_hashtable;
 
-extern char *string_strndup (const char *string, int length);
+extern char *string_strndup (const char *string, int bytes);
 extern char *string_cut (const char *string, int length, int count_suffix,
                          int screen, const char *cut_suffix);
 extern char *string_reverse (const char *string);
@@ -71,6 +71,7 @@ extern char *string_remove_quotes (const char *string, const char *quotes);
 extern char *string_strip (const char *string, int left, int right,
                            const char *chars);
 extern char *string_convert_escaped_chars (const char *string);
+extern int string_is_whitespace_char (const char *string);
 extern int string_is_word_char_highlight (const char *string);
 extern int string_is_word_char_input (const char *string);
 extern char *string_mask_to_regex (const char *mask);
@@ -96,8 +97,9 @@ extern char **string_split_shared (const char *string, const char *separators,
 extern char **string_split_shell (const char *string, int *num_items);
 extern void string_free_split (char **split_string);
 extern void string_free_split_shared (char **split_string);
-extern char *string_build_with_split_string (const char **split_string,
-                                             const char *separator);
+extern char *string_rebuild_split_string (const char **split_string,
+                                          const char *separator,
+                                          int index_start, int index_end);
 extern char **string_split_command (const char *command, char separator);
 extern void string_free_split_command (char **split_command);
 extern char ***string_split_tags (const char *tags, int *num_tags);
@@ -109,6 +111,7 @@ extern char *string_iconv_from_internal (const char *charset,
                                          const char *string);
 extern int string_fprintf (FILE *file, const char *data, ...);
 extern char *string_format_size (unsigned long long size);
+extern unsigned long long string_parse_size (const char *size);
 extern int string_base16_encode (const char *from, int length, char *to);
 extern int string_base16_decode (const char *from, char *to);
 extern int string_base32_encode (const char *from, int length, char *to);
