@@ -292,6 +292,7 @@ gui_chat_string_next_char (struct t_gui_window *window, struct t_gui_line *line,
                             case GUI_COLOR_BAR_MOVE_CURSOR_CHAR:
                             case GUI_COLOR_BAR_START_ITEM:
                             case GUI_COLOR_BAR_START_LINE_ITEM:
+                            case GUI_COLOR_BAR_SPACER:
                                 string++;
                                 break;
                         }
@@ -1805,6 +1806,13 @@ gui_chat_calculate_line_diff (struct t_gui_window *window,
             *line_pos = 0;
         }
     }
+
+    /* special case for bare display */
+    if (gui_window_bare_display && backward && (*line_pos > 0))
+    {
+        *line = gui_line_get_next_displayed (*line);
+        *line_pos = 0;
+    }
 }
 
 /*
