@@ -199,6 +199,8 @@ struct t_gui_buffer
     char *highlight_words;             /* list of words to highlight        */
     char *highlight_regex;             /* regex for highlight               */
     regex_t *highlight_regex_compiled; /* compiled regex                    */
+    char *highlight_disable_regex;     /* regex for disabling highlight     */
+    regex_t *highlight_disable_regex_compiled; /* compiled regex            */
     char *highlight_tags_restrict;     /* restrict highlight to these tags  */
     int highlight_tags_restrict_count; /* number of restricted tags         */
     char ***highlight_tags_restrict_array; /* array with restricted tags    */
@@ -316,8 +318,10 @@ extern void gui_buffer_set_title (struct t_gui_buffer *buffer,
                                   const char *new_title);
 extern void gui_buffer_set_highlight_words (struct t_gui_buffer *buffer,
                                             const char *new_highlight_words);
+extern void gui_buffer_set_highlight_disable_regex (struct t_gui_buffer *buffer,
+                                                    const char *new_regex);
 extern void gui_buffer_set_highlight_regex (struct t_gui_buffer *buffer,
-                                            const char *new_highlight_regex);
+                                            const char *new_regex);
 extern void gui_buffer_set_highlight_tags_restrict (struct t_gui_buffer *buffer,
                                                     const char *new_tags);
 extern void gui_buffer_set_highlight_tags (struct t_gui_buffer *buffer,
