@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2022 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_PLUGIN_BUFLIST_H
@@ -25,6 +25,8 @@
 
 #define BUFLIST_BAR_NAME "buflist"
 
+struct t_gui_bar_item;
+
 extern struct t_weechat_plugin *weechat_buflist_plugin;
 
 extern struct t_hdata *buflist_hdata_window;
@@ -35,8 +37,9 @@ extern struct t_hdata *buflist_hdata_bar_item;
 extern struct t_hdata *buflist_hdata_bar_window;
 
 extern void buflist_add_bar ();
-extern void buflist_buffer_get_irc_pointers(struct t_gui_buffer *buffer,
-                                            void **irc_server, void **irc_channel);
-extern struct t_arraylist *buflist_sort_buffers ();
+extern void buflist_buffer_get_irc_pointers (struct t_gui_buffer *buffer,
+                                             void **irc_server,
+                                             void **irc_channel);
+extern struct t_arraylist *buflist_sort_buffers (struct t_gui_bar_item *item);
 
 #endif /* WEECHAT_PLUGIN_BUFLIST_H */
