@@ -1,7 +1,7 @@
 /*
  * weechat-guile.c - guile (scheme) plugin for WeeChat
  *
- * Copyright (C) 2011-2021 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2011-2022 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -598,10 +598,14 @@ weechat_guile_load (const char *filename, const char *code)
 void
 weechat_guile_load_cb (void *data, const char *filename)
 {
+    const char *pos_dot;
+
     /* make C compiler happy */
     (void) data;
 
-    weechat_guile_load (filename, NULL);
+    pos_dot = strrchr (filename, '.');
+    if (pos_dot && (strcmp (pos_dot, ".scm") == 0))
+        weechat_guile_load (filename, NULL);
 }
 
 /*
@@ -1257,14 +1261,14 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     if (!guile_buffer_output)
         return WEECHAT_RC_ERROR;
 
-#ifdef HAVE_GUILE_GMP_MEMORY_FUNCTIONS
+#if defined(HAVE_GUILE_GMP_MEMORY_FUNCTIONS) && (SCM_MAJOR_VERSION < 3 || (SCM_MAJOR_VERSION == 3 && SCM_MINOR_VERSION == 0 && SCM_MICRO_VERSION < 8))
     /*
      * prevent guile to use its own gmp allocator, because it can conflict
      * with other plugins using GnuTLS like relay, which can crash WeeChat
-     * on unload (or exit)
+     * on unload (or exit); this is not needed any more with Guile ≥ 3.0.8
      */
     scm_install_gmp_memory_functions = 0;
-#endif /* HAVE_GUILE_GMP_MEMORY_FUNCTIONS */
+#endif /* defined(HAVE_GUILE_GMP_MEMORY_FUNCTIONS) && (SCM_MAJOR_VERSION < 3 || (SCM_MAJOR_VERSION == 3 && SCM_MINOR_VERSION == 0 && SCM_MICRO_VERSION < 8)) */
 
     scm_init_guile ();
 
