@@ -1176,7 +1176,7 @@ irc_channel_join_smart_filtered_unmask (struct t_irc_channel *channel,
                                         const char *nick)
 {
     int i, unmask_delay, length_tags, nick_found, join, account;
-    int chghost, nick_changed, smart_filtered, remove_smart_filter;
+    int chghost, setname, nick_changed, smart_filtered, remove_smart_filter;
     time_t *ptr_time, date_min;
     struct t_hdata *hdata_line, *hdata_line_data;
     struct t_gui_line *own_lines;
@@ -1254,6 +1254,7 @@ irc_channel_join_smart_filtered_unmask (struct t_irc_channel *channel,
             join = 0;
             account = 0;
             chghost = 0;
+            setname = 0;
             nick_changed = 0;
             irc_nick1 = NULL;
             irc_nick2 = NULL;
@@ -1271,6 +1272,8 @@ irc_channel_join_smart_filtered_unmask (struct t_irc_channel *channel,
                     account = 1;
                 else if (strcmp (tags[i], "irc_chghost") == 0)
                     chghost = 1;
+                else if (strcmp (tags[i], "irc_setname") == 0)
+                    setname = 1;
                 else if (strcmp (tags[i], "irc_nick") == 0)
                     nick_changed = 1;
                 else if (strncmp (tags[i], "irc_nick1_", 10) == 0)
@@ -1294,7 +1297,8 @@ irc_channel_join_smart_filtered_unmask (struct t_irc_channel *channel,
                     break;
                 remove_smart_filter = 1;
             }
-            else if (nick_found && (join || account || chghost) && smart_filtered)
+            else if (nick_found && (join || account || chghost || setname)
+                     && smart_filtered)
             {
                 remove_smart_filter = 1;
             }
