@@ -534,7 +534,7 @@ irc_info_infolist_irc_server_cb (const void *pointer, void *data,
     if (obj_pointer)
     {
         /* build list with only one server */
-        if (!irc_server_add_to_infolist (ptr_infolist, obj_pointer))
+        if (!irc_server_add_to_infolist (ptr_infolist, obj_pointer, 0))
         {
             weechat_infolist_free (ptr_infolist);
             return NULL;
@@ -550,7 +550,7 @@ irc_info_infolist_irc_server_cb (const void *pointer, void *data,
             if (!arguments || !arguments[0]
                 || weechat_string_match (ptr_server->name, arguments, 0))
             {
-                if (!irc_server_add_to_infolist (ptr_infolist, ptr_server))
+                if (!irc_server_add_to_infolist (ptr_infolist, ptr_server, 0))
                 {
                     weechat_infolist_free (ptr_infolist);
                     return NULL;
