@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2022 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_PLUGIN_IRC_MODE_H
@@ -23,12 +23,14 @@
 struct t_irc_server;
 struct t_irc_channel;
 
+extern char *irc_mode_get_arguments (const char *arguments);
 extern char irc_mode_get_chanmode_type (struct t_irc_server *server,
                                         char chanmode);
 extern int irc_mode_channel_set (struct t_irc_server *server,
                                  struct t_irc_channel *channel,
                                  const char *host,
-                                 const char *modes);
+                                 const char *modes,
+                                 const char *modes_arguments);
 extern void irc_mode_user_set (struct t_irc_server *server, const char *modes,
                                int reset_modes);
 
