@@ -37,7 +37,7 @@ enum t_irc_upgrade_type
     IRC_UPGRADE_TYPE_MODELIST_ITEM,
 };
 
-extern int irc_upgrade_save ();
+extern int irc_upgrade_save (int force_disconnected_state);
 extern int irc_upgrade_load ();
 
 #endif /* WEECHAT_PLUGIN_IRC_UPGRADE_H */
