@@ -2,7 +2,7 @@
  * weechat-js.cpp - javascript plugin for WeeChat
  *
  * Copyright (C) 2013 Koka El Kiwi <kokakiwi@kokakiwi.net>
- * Copyright (C) 2015-2021 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2015-2022 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -417,10 +417,14 @@ weechat_js_load (const char *filename, const char *code)
 void
 weechat_js_load_cb (void *data, const char *filename)
 {
+    const char *pos_dot;
+
     /* make C++ compiler happy */
     (void) data;
 
-    weechat_js_load (filename, NULL);
+    pos_dot = strrchr (filename, '.');
+    if (pos_dot && (strcmp (pos_dot, ".js") == 0))
+        weechat_js_load (filename, NULL);
 }
 
 /*
