@@ -22,7 +22,6 @@
 
 #define LOGGER_CONFIG_NAME "logger"
 
-
 extern struct t_config_option *logger_config_look_backlog;
 extern struct t_config_option *logger_config_look_backlog_conditions;
 
@@ -40,8 +39,13 @@ extern struct t_config_option *logger_config_file_nick_prefix;
 extern struct t_config_option *logger_config_file_nick_suffix;
 extern struct t_config_option *logger_config_file_path;
 extern struct t_config_option *logger_config_file_replacement_char;
+extern struct t_config_option *logger_config_file_rotation_compression_level;
+extern struct t_config_option *logger_config_file_rotation_compression_type;
+extern struct t_config_option *logger_config_file_rotation_size_max;
 extern struct t_config_option *logger_config_file_time_format;
 
+extern unsigned long long logger_config_rotation_size_max;
+
 extern struct t_config_option *logger_config_get_level (const char *name);
 extern int logger_config_set_level (const char *name, const char *value);
 extern struct t_config_option *logger_config_get_mask (const char *name);
