@@ -2,7 +2,7 @@
  * weechat-lua.c - lua plugin for WeeChat
  *
  * Copyright (C) 2006-2007 Emmanuel Bouthenot <kolter@openics.org>
- * Copyright (C) 2006-2021 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2006-2022 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -696,10 +696,14 @@ weechat_lua_load (const char *filename, const char *code)
 void
 weechat_lua_load_cb (void *data, const char *filename)
 {
+    const char *pos_dot;
+
     /* make C compiler happy */
     (void) data;
 
-    weechat_lua_load (filename, NULL);
+    pos_dot = strrchr (filename, '.');
+    if (pos_dot && (strcmp (pos_dot, ".lua") == 0))
+        weechat_lua_load (filename, NULL);
 }
 
 /*
