@@ -629,10 +629,11 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->string_split = &string_split;
         new_plugin->string_split_shell = &string_split_shell;
         new_plugin->string_free_split = &string_free_split;
-        new_plugin->string_build_with_split_string = &string_build_with_split_string;
+        new_plugin->string_rebuild_split_string = &string_rebuild_split_string;
         new_plugin->string_split_command = &string_split_command;
         new_plugin->string_free_split_command = &string_free_split_command;
         new_plugin->string_format_size = &string_format_size;
+        new_plugin->string_parse_size = &string_parse_size;
         new_plugin->string_color_code_size = &gui_color_code_size;
         new_plugin->string_remove_color = &gui_color_decode;
         new_plugin->string_base_encode = &string_base_encode;
@@ -665,6 +666,7 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->utf8_strndup = &utf8_strndup;
 
         new_plugin->crypto_hash = &plugin_api_crypto_hash;
+        new_plugin->crypto_hash_file = &plugin_api_crypto_hash_file;
         new_plugin->crypto_hash_pbkdf2 = &plugin_api_crypto_hash_pbkdf2;
         new_plugin->crypto_hmac = &plugin_api_crypto_hmac;
 
@@ -674,6 +676,7 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->exec_on_files = &dir_exec_on_files;
         new_plugin->file_get_content = &dir_file_get_content;
         new_plugin->file_copy = &dir_file_copy;
+        new_plugin->file_compress = &dir_file_compress;
 
         new_plugin->util_timeval_cmp = &util_timeval_cmp;
         new_plugin->util_timeval_diff = &util_timeval_diff;
