@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2022 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -26,7 +26,7 @@
 
 struct t_relay_server
 {
-    char *protocol_string;             /* example: "ipv6.ssl.irc.freenode"  */
+    char *protocol_string;             /* example: "ipv6.ssl.irc.libera"    */
     enum t_relay_protocol protocol;    /* protocol (irc/weechat)            */
     char *protocol_args;               /* arguments used for protocol       */
                                        /* example: server for irc protocol  */
