@@ -76,7 +76,8 @@ extern void relay_weechat_alloc_with_infolist (struct t_relay_client *client,
 extern enum t_relay_status relay_weechat_get_initial_status (struct t_relay_client *client);
 extern void relay_weechat_free (struct t_relay_client *client);
 extern int relay_weechat_add_to_infolist (struct t_infolist_item *item,
-                                          struct t_relay_client *client);
+                                          struct t_relay_client *client,
+                                          int force_disconnected_state);
 extern void relay_weechat_print_log (struct t_relay_client *client);
 
 #endif /* WEECHAT_PLUGIN_RELAY_WEECHAT_H */
