@@ -2,7 +2,7 @@
  * weechat-tcl.c - tcl plugin for WeeChat
  *
  * Copyright (C) 2008-2010 Dmitry Kobylin <fnfal@academ.tsc.ru>
- * Copyright (C) 2008-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2008-2022 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,7 +17,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #undef _
@@ -44,7 +44,20 @@ WEECHAT_PLUGIN_PRIORITY(4000);
 
 struct t_weechat_plugin *weechat_tcl_plugin = NULL;
 
+struct t_plugin_script_data tcl_data;
+
+struct t_config_file *tcl_config_file = NULL;
+struct t_config_option *tcl_config_look_check_license = NULL;
+struct t_config_option *tcl_config_look_eval_keep_context = NULL;
+
 int tcl_quiet = 0;
+
+struct t_plugin_script *tcl_script_eval = NULL;
+int tcl_eval_mode = 0;
+int tcl_eval_send_input = 0;
+int tcl_eval_exec_commands = 0;
+struct t_gui_buffer *tcl_eval_buffer = NULL;
+
 struct t_plugin_script *tcl_scripts = NULL;
 struct t_plugin_script *last_tcl_script = NULL;
 struct t_plugin_script *tcl_current_script = NULL;
@@ -151,7 +164,7 @@ weechat_tcl_dict_to_hashtable (Tcl_Interp *interp, Tcl_Obj *dict,
 
     if (Tcl_DictObjFirst (interp, dict, &search, &key, &value, &done) == TCL_OK)
     {
-        for (; !done ; Tcl_DictObjNext(&search, &key, &value, &done))
+        for (; !done ; Tcl_DictObjNext (&search, &key, &value, &done))
         {
             if (strcmp (type_values, WEECHAT_HASHTABLE_STRING) == 0)
             {
@@ -237,8 +250,9 @@ weechat_tcl_exec (struct t_plugin_script *script,
 
     if (Tcl_EvalObjEx (interp, cmdlist, TCL_EVAL_DIRECT) == TCL_OK)
     {
-        Tcl_ListObjReplace (interp, cmdlist, 0, llength, 0, NULL); /* remove elements, decrement their ref count */
-        Tcl_DecrRefCount (cmdlist); /* -1 */
+        /* remove elements, decrement their ref count */
+        Tcl_ListObjReplace (interp, cmdlist, 0, llength, 0, NULL);
+        Tcl_DecrRefCount (cmdlist);  /* -1 */
         ret_val = NULL;
         if (ret_type == WEECHAT_SCRIPT_EXEC_STRING)
         {
@@ -248,6 +262,18 @@ weechat_tcl_exec (struct t_plugin_script *script,
             else
                 ret_val = NULL;
         }
+        else if (ret_type == WEECHAT_SCRIPT_EXEC_POINTER)
+        {
+            ret_cv = Tcl_GetStringFromObj (Tcl_GetObjResult (interp), &i);
+            if (ret_cv)
+            {
+                ret_val = plugin_script_str2ptr (weechat_tcl_plugin,
+                                                 script->name, function,
+                                                 ret_cv);
+            }
+            else
+                ret_val = NULL;
+        }
         else if ( ret_type == WEECHAT_SCRIPT_EXEC_INT
                   && Tcl_GetIntFromObj (interp, Tcl_GetObjResult (interp), &i) == TCL_OK)
         {
@@ -269,15 +295,21 @@ weechat_tcl_exec (struct t_plugin_script *script,
         if (ret_val)
             return ret_val;
 
-        weechat_printf (NULL,
-                        weechat_gettext ("%s%s: function \"%s\" must return a "
-                                         "valid value"),
-                        weechat_prefix ("error"), TCL_PLUGIN_NAME, function);
+        if (ret_type != WEECHAT_SCRIPT_EXEC_IGNORE)
+        {
+            weechat_printf (NULL,
+                            weechat_gettext ("%s%s: function \"%s\" must "
+                                             "return a valid value"),
+                            weechat_prefix ("error"), TCL_PLUGIN_NAME,
+                            function);
+        }
+
         return NULL;
     }
 
-    Tcl_ListObjReplace (interp, cmdlist, 0, llength, 0, NULL); /* remove elements, decrement their ref count */
-    Tcl_DecrRefCount (cmdlist); /* -1 */
+    /* remove elements, decrement their ref count */
+    Tcl_ListObjReplace (interp, cmdlist, 0, llength, 0, NULL);
+    Tcl_DecrRefCount (cmdlist);  /* -1 */
     weechat_printf (NULL,
                     weechat_gettext ("%s%s: unable to run function \"%s\": %s"),
                     weechat_prefix ("error"), TCL_PLUGIN_NAME, function,
@@ -290,24 +322,29 @@ weechat_tcl_exec (struct t_plugin_script *script,
 /*
  * Loads a tcl script.
  *
- * Returns:
- *   1: OK
- *   0: error
+ * If code is NULL, the content of filename is read and executed.
+ * If code is not NULL, it is executed (the file is not read).
+ *
+ * Returns pointer to new registered script, NULL if error.
  */
 
-int
-weechat_tcl_load (const char *filename)
+struct t_plugin_script *
+weechat_tcl_load (const char *filename, const char *code)
 {
     int i;
     Tcl_Interp *interp;
     struct stat buf;
 
+    /* make C compiler happy */
+    /* TODO: implement load of code in TCL */
+    (void) code;
+
     if (stat (filename, &buf) != 0)
     {
         weechat_printf (NULL,
                         weechat_gettext ("%s%s: script \"%s\" not found"),
                         weechat_prefix ("error"), TCL_PLUGIN_NAME, filename);
-        return 0;
+        return NULL;
     }
 
     if ((weechat_tcl_plugin->debug >= 2) || !tcl_quiet)
@@ -325,7 +362,7 @@ weechat_tcl_load (const char *filename)
                         weechat_gettext ("%s%s: unable to create new "
                                          "interpreter"),
                         weechat_prefix ("error"), TCL_PLUGIN_NAME);
-        return 0;
+        return NULL;
     }
     tcl_current_script_filename = filename;
 
@@ -348,7 +385,7 @@ weechat_tcl_load (const char *filename)
             tcl_current_script = NULL;
         }
 
-        return 0;
+        return NULL;
     }
 
     if (!tcl_registered_script)
@@ -358,7 +395,7 @@ weechat_tcl_load (const char *filename)
                                          "found (or failed) in file \"%s\""),
                         weechat_prefix ("error"), TCL_PLUGIN_NAME, filename);
         Tcl_DeleteInterp (interp);
-        return 0;
+        return NULL;
     }
     tcl_current_script = tcl_registered_script;
 
@@ -376,7 +413,7 @@ weechat_tcl_load (const char *filename)
                                      WEECHAT_HOOK_SIGNAL_STRING,
                                      tcl_current_script->filename);
 
-    return 1;
+    return tcl_current_script;
 }
 
 /*
@@ -386,10 +423,14 @@ weechat_tcl_load (const char *filename)
 void
 weechat_tcl_load_cb (void *data, const char *filename)
 {
+    const char *pos_dot;
+
     /* make C compiler happy */
     (void) data;
 
-    weechat_tcl_load (filename);
+    pos_dot = strrchr (filename, '.');
+    if (pos_dot && (strcmp (pos_dot, ".tcl") == 0))
+        weechat_tcl_load (filename, NULL);
 }
 
 /*
@@ -429,7 +470,7 @@ weechat_tcl_unload (struct t_plugin_script *script)
 
     plugin_script_remove (weechat_tcl_plugin, &tcl_scripts, &last_tcl_script, script);
 
-    Tcl_DeleteInterp(interp);
+    Tcl_DeleteInterp (interp);
 
     (void) weechat_hook_signal_send ("tcl_script_unloaded",
                                      WEECHAT_HOOK_SIGNAL_STRING, filename);
@@ -501,7 +542,7 @@ weechat_tcl_reload_name (const char *name)
                                 weechat_gettext ("%s: script \"%s\" unloaded"),
                                 TCL_PLUGIN_NAME, name);
             }
-            weechat_tcl_load (filename);
+            weechat_tcl_load (filename, NULL);
             free (filename);
         }
     }
@@ -513,6 +554,27 @@ weechat_tcl_reload_name (const char *name)
     }
 }
 
+/*
+ * Evaluates TCL source code.
+ *
+ * Returns:
+ *   1: OK
+ *   0: error
+ */
+
+int
+weechat_tcl_eval (struct t_gui_buffer *buffer, int send_to_buffer_as_input,
+                  int exec_commands, const char *code)
+{
+    /* TODO: implement tcl eval */
+    (void) buffer;
+    (void) send_to_buffer_as_input;
+    (void) exec_commands;
+    (void) code;
+
+    return 1;
+}
+
 /*
  * Callback for command "/tcl".
  */
@@ -522,12 +584,12 @@ weechat_tcl_command_cb (const void *pointer, void *data,
                         struct t_gui_buffer *buffer,
                          int argc, char **argv, char **argv_eol)
 {
-    char *ptr_name, *path_script;
+    char *ptr_name, *ptr_code, *path_script;
+    int i, send_to_buffer_as_input, exec_commands;
 
     /* make C compiler happy */
     (void) pointer;
     (void) data;
-    (void) buffer;
 
     if (argc == 1)
     {
@@ -559,6 +621,10 @@ weechat_tcl_command_cb (const void *pointer, void *data,
         {
             weechat_tcl_unload_all ();
         }
+        else if (weechat_strcasecmp (argv[1], "version") == 0)
+        {
+            plugin_script_display_interpreter (weechat_tcl_plugin, 0);
+        }
         else
             WEECHAT_COMMAND_ERROR;
     }
@@ -593,7 +659,8 @@ weechat_tcl_command_cb (const void *pointer, void *data,
                 /* load tcl script */
                 path_script = plugin_script_search_path (weechat_tcl_plugin,
                                                          ptr_name);
-                weechat_tcl_load ((path_script) ? path_script : ptr_name);
+                weechat_tcl_load ((path_script) ? path_script : ptr_name,
+                                  NULL);
                 if (path_script)
                     free (path_script);
             }
@@ -609,6 +676,44 @@ weechat_tcl_command_cb (const void *pointer, void *data,
             }
             tcl_quiet = 0;
         }
+        else if (weechat_strcasecmp (argv[1], "eval") == 0)
+        {
+            send_to_buffer_as_input = 0;
+            exec_commands = 0;
+            ptr_code = argv_eol[2];
+            for (i = 2; i < argc; i++)
+            {
+                if (argv[i][0] == '-')
+                {
+                    if (strcmp (argv[i], "-o") == 0)
+                    {
+                        if (i + 1 >= argc)
+                            WEECHAT_COMMAND_ERROR;
+                        send_to_buffer_as_input = 1;
+                        exec_commands = 0;
+                        ptr_code = argv_eol[i + 1];
+                    }
+                    else if (strcmp (argv[i], "-oc") == 0)
+                    {
+                        if (i + 1 >= argc)
+                            WEECHAT_COMMAND_ERROR;
+                        send_to_buffer_as_input = 1;
+                        exec_commands = 1;
+                        ptr_code = argv_eol[i + 1];
+                    }
+                }
+                else
+                    break;
+            }
+            if (!weechat_tcl_eval (buffer, send_to_buffer_as_input,
+                                   exec_commands, ptr_code))
+                WEECHAT_COMMAND_ERROR;
+            /* TODO: implement /tcl eval */
+            weechat_printf (NULL,
+                            _("%sCommand \"/%s eval\" is not yet implemented"),
+                            weechat_prefix ("error"),
+                            weechat_tcl_plugin->name);
+        }
         else
             WEECHAT_COMMAND_ERROR;
     }
@@ -654,6 +759,26 @@ weechat_tcl_hdata_cb (const void *pointer, void *data,
                                        hdata_name);
 }
 
+/*
+ * Returns tcl info "tcl_eval".
+ */
+
+char *
+weechat_tcl_info_eval_cb (const void *pointer, void *data,
+                          const char *info_name,
+                          const char *arguments)
+{
+    const char *not_implemented = "not yet implemented";
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) info_name;
+    (void) arguments;
+
+    return strdup (not_implemented);
+}
+
 /*
  * Returns infolist with tcl scripts.
  */
@@ -704,31 +829,6 @@ weechat_tcl_signal_debug_dump_cb (const void *pointer, void *data,
     return WEECHAT_RC_OK;
 }
 
-/*
- * Display infos about external libraries used.
- */
-
-int
-weechat_tcl_signal_debug_libs_cb (const void *pointer, void *data,
-                                  const char *signal,
-                                  const char *type_data, void *signal_data)
-{
-    /* make C compiler happy */
-    (void) pointer;
-    (void) data;
-    (void) signal;
-    (void) type_data;
-    (void) signal_data;
-
-#ifdef TCL_VERSION
-    weechat_printf (NULL, "  %s: %s", TCL_PLUGIN_NAME, TCL_VERSION);
-#else
-    weechat_printf (NULL, "  %s: (?)", TCL_PLUGIN_NAME);
-#endif /* TCL_VERSION */
-
-    return WEECHAT_RC_OK;
-}
-
 /*
  * Timer for executing actions.
  */
@@ -823,21 +923,36 @@ weechat_tcl_signal_script_action_cb (const void *pointer, void *data,
 int
 weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
 {
-    struct t_plugin_script_init init;
-
     weechat_tcl_plugin = plugin;
 
-    init.callback_command = &weechat_tcl_command_cb;
-    init.callback_completion = &weechat_tcl_completion_cb;
-    init.callback_hdata = &weechat_tcl_hdata_cb;
-    init.callback_infolist = &weechat_tcl_infolist_cb;
-    init.callback_signal_debug_dump = &weechat_tcl_signal_debug_dump_cb;
-    init.callback_signal_debug_libs = &weechat_tcl_signal_debug_libs_cb;
-    init.callback_signal_script_action = &weechat_tcl_signal_script_action_cb;
-    init.callback_load_file = &weechat_tcl_load_cb;
+    /* set interpreter name and version */
+    weechat_hashtable_set (plugin->variables, "interpreter_name",
+                           plugin->name);
+#ifdef TCL_VERSION
+    weechat_hashtable_set (plugin->variables, "interpreter_version",
+                           TCL_VERSION);
+#else
+    weechat_hashtable_set (plugin->variables, "interpreter_version",
+                           "");
+#endif /* TCL_VERSION */
+
+    tcl_data.config_file = &tcl_config_file;
+    tcl_data.config_look_check_license = &tcl_config_look_check_license;
+    tcl_data.config_look_eval_keep_context = &tcl_config_look_eval_keep_context;
+    tcl_data.scripts = &tcl_scripts;
+    tcl_data.last_script = &last_tcl_script;
+    tcl_data.callback_command = &weechat_tcl_command_cb;
+    tcl_data.callback_completion = &weechat_tcl_completion_cb;
+    tcl_data.callback_hdata = &weechat_tcl_hdata_cb;
+    tcl_data.callback_info_eval = &weechat_tcl_info_eval_cb;
+    tcl_data.callback_infolist = &weechat_tcl_infolist_cb;
+    tcl_data.callback_signal_debug_dump = &weechat_tcl_signal_debug_dump_cb;
+    tcl_data.callback_signal_script_action = &weechat_tcl_signal_script_action_cb;
+    tcl_data.callback_load_file = &weechat_tcl_load_cb;
+    tcl_data.unload_all = &weechat_tcl_unload_all;
 
     tcl_quiet = 1;
-    plugin_script_init (weechat_tcl_plugin, argc, argv, &init);
+    plugin_script_init (weechat_tcl_plugin, argc, argv, &tcl_data);
     tcl_quiet = 0;
 
     plugin_script_display_short_list (weechat_tcl_plugin,
@@ -856,7 +971,12 @@ weechat_plugin_end (struct t_weechat_plugin *plugin)
 {
     /* unload all scripts */
     tcl_quiet = 1;
-    plugin_script_end (plugin, &tcl_scripts, &weechat_tcl_unload_all);
+    if (tcl_script_eval)
+    {
+        weechat_tcl_unload (tcl_script_eval);
+        tcl_script_eval = NULL;
+    }
+    plugin_script_end (plugin, &tcl_data);
     tcl_quiet = 0;
 
     /* free some data */
@@ -866,6 +986,7 @@ weechat_plugin_end (struct t_weechat_plugin *plugin)
         free (tcl_action_remove_list);
     if (tcl_action_autoload_list)
         free (tcl_action_autoload_list);
+    /* weechat_string_dyn_free (tcl_buffer_output, 1); */
 
     return WEECHAT_RC_OK;
 }
