@@ -22,14 +22,14 @@
 
 #define TRIGGER_BUFFER_NAME "monitor"
 
+struct t_trigger_context;
+
 extern struct t_gui_buffer *trigger_buffer;
 
 extern void trigger_buffer_set_callbacks ();
 extern void trigger_buffer_open (const char *filter, int switch_to_buffer);
 extern int trigger_buffer_display_trigger (struct t_trigger *trigger,
-                                           struct t_gui_buffer *buffer,
-                                           struct t_hashtable *pointers,
-                                           struct t_hashtable *extra_vars);
+                                           struct t_trigger_context *context);
 extern void trigger_buffer_end ();
 
 #endif /* WEECHAT_PLUGIN_TRIGGER_BUFFER_H */
