@@ -29,9 +29,7 @@
 #include <time.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
-#include <arpa/nameser.h>
 #include <netdb.h>
-#include <resolv.h>
 #include <gcrypt.h>
 #include <arpa/inet.h>
 
@@ -128,10 +126,22 @@ xfer_signal_upgrade_cb (const void *pointer, void *data,
     (void) signal;
     (void) type_data;
 
+    /* only save session and continue? */
+    if (signal_data && (strcmp (signal_data, "save") == 0))
+    {
+        xfer_upgrade_save ();
+        return WEECHAT_RC_OK;
+    }
+
     xfer_signal_upgrade_received = 1;
 
-    if (signal_data && (strcmp (signal_data, "quit") == 0))
-        xfer_disconnect_all ();
+    /*
+     * TODO: do not disconnect here in case of upgrade when the save of xfers
+     * in upgrade file will be implemented
+     * (see function xfer_upgrade_save_xfers in xfer-upgrade.c)
+     */
+    /*if (signal_data && (strcmp (signal_data, "quit") == 0))*/
+    xfer_disconnect_all ();
 
     return WEECHAT_RC_OK;
 }
@@ -418,7 +428,9 @@ xfer_disconnect_all ()
                                     ptr_xfer->filename,
                                     ptr_xfer->remote_nick);
             }
-            xfer_close (ptr_xfer, XFER_STATUS_FAILED);
+            xfer_close (ptr_xfer,
+                        (XFER_IS_CHAT(ptr_xfer->type)) ?
+                        XFER_STATUS_ABORTED : XFER_STATUS_FAILED);
         }
     }
 }
@@ -604,59 +616,6 @@ xfer_nick_auto_accepted (const char *server, const char *nick)
     return rc;
 }
 
-/*
- * Searches CRC32 in a filename.
- *
- * If more than one CRC32 are found, the last one is returned
- * (with the higher index in filename).
- *
- * The chars before/after CRC32 must be either beginning/end of string or
- * non-hexadecimal chars.
- *
- * Examples:
- *
- *   test_filename     => -1 (not found: no CRC32)
- *   test_1234abcd     => 5  ("1234abcd")
- *   1234abcd_test     => 0  ("1234abcd")
- *   1234abcd_12345678 => 9  ("12345678")
- *   123456789abcdef   => -1 (not found: missing delimiter around CRC32)
- *
- * Returns pointer to last CRC32 in string, NULL if no CRC32 was found.
- */
-
-const char *
-xfer_filename_crc32 (const char *filename)
-{
-    int length;
-    const char *ptr_string, *ptr_crc32;
-
-    length = 0;
-    ptr_crc32 = NULL;
-
-    ptr_string = filename;
-    while (ptr_string && ptr_string[0])
-    {
-        if (((ptr_string[0] >= '0') && (ptr_string[0] <= '9'))
-            || ((ptr_string[0] >= 'A') && (ptr_string[0] <= 'F'))
-            || ((ptr_string[0] >= 'a') && (ptr_string[0] <= 'f')))
-        {
-            length++;
-        }
-        else
-        {
-            if (length == 8)
-                ptr_crc32 = ptr_string - 8;
-            length = 0;
-        }
-
-        ptr_string = weechat_utf8_next_char (ptr_string);
-    }
-    if (length == 8)
-        ptr_crc32 = ptr_string - 8;
-
-    return ptr_crc32;
-}
-
 /*
  * Adds a xfer to list.
  *
@@ -748,7 +707,7 @@ xfer_new (const char *plugin_name, const char *plugin_id,
     if ((type == XFER_TYPE_FILE_RECV)
         && weechat_config_boolean (xfer_config_file_auto_check_crc32))
     {
-        ptr_crc32 = xfer_filename_crc32 (new_xfer->filename);
+        ptr_crc32 = xfer_file_search_crc32 (new_xfer->filename);
         if (ptr_crc32)
         {
             new_xfer->hash_handle = malloc (sizeof (gcry_md_hd_t));
@@ -965,8 +924,6 @@ xfer_free (struct t_xfer *xfer)
         free (xfer->remote_address);
     if (xfer->remote_address_str)
         free (xfer->remote_address_str);
-    if (xfer->buffer)
-        free (xfer->buffer);
     if (xfer->remote_nick_color)
         free (xfer->remote_nick_color);
     if (xfer->hook_fd)
@@ -1011,59 +968,6 @@ xfer_free_all ()
     }
 }
 
-/*
- * Resolves address.
- *
- * Returns:
- *   1: OK
- *   0: error
- */
-
-int
-xfer_resolve_addr (const char *str_address, const char *str_port,
-                   struct sockaddr *addr, socklen_t *addr_len, int ai_flags)
-{
-    struct addrinfo *ainfo, hints;
-    int rc;
-
-    memset (&hints, 0, sizeof (struct addrinfo));
-    hints.ai_flags = ai_flags;
-    hints.ai_family = AF_UNSPEC;
-    hints.ai_socktype = SOCK_STREAM;
-    hints.ai_protocol = 0;
-    hints.ai_canonname = NULL;
-    hints.ai_addr = NULL;
-    hints.ai_next = NULL;
-
-    res_init ();
-    rc = getaddrinfo (str_address, str_port, &hints, &ainfo);
-    if ((rc == 0) && ainfo && ainfo->ai_addr)
-    {
-        if (ainfo->ai_addrlen > *addr_len)
-        {
-            weechat_printf (NULL,
-                            _("%s%s: address \"%s\" resolved to a larger "
-                              "sockaddr than expected"),
-                            weechat_prefix ("error"), XFER_PLUGIN_NAME,
-                            str_address);
-            freeaddrinfo (ainfo);
-            return 0;
-        }
-        memcpy (addr, ainfo->ai_addr, ainfo->ai_addrlen);
-        *addr_len = ainfo->ai_addrlen;
-        freeaddrinfo (ainfo);
-        return 1;
-    }
-
-    weechat_printf (NULL,
-                    _("%s%s: invalid address \"%s\": error %d %s"),
-                    weechat_prefix ("error"), XFER_PLUGIN_NAME,
-                    str_address, rc, gai_strerror (rc));
-    if ((rc == 0) && ainfo)
-        freeaddrinfo (ainfo);
-    return 0;
-}
-
 /*
  * Callback for signal "xfer_add".
  */
@@ -1249,9 +1153,9 @@ xfer_add_cb (const void *pointer, void *data,
         snprintf (str_port_temp, sizeof (str_port_temp), "%d", port);
         str_port = str_port_temp;
         length = sizeof (addr);
-        if (!xfer_resolve_addr (str_address, str_port,
-                                (struct sockaddr*)&addr, &length,
-                                AI_NUMERICSERV | AI_NUMERICHOST))
+        if (!xfer_network_resolve_addr (str_address, str_port,
+                                        (struct sockaddr*)&addr, &length,
+                                        AI_NUMERICSERV | AI_NUMERICHOST))
         {
             goto error;
         }
@@ -1268,9 +1172,10 @@ xfer_add_cb (const void *pointer, void *data,
             str_address = weechat_config_string (xfer_config_network_own_ip);
             length = sizeof (own_ip_addr);
 
-            if (!xfer_resolve_addr (str_address, NULL,
-                                    (struct sockaddr*)&own_ip_addr, &length,
-                                    AI_NUMERICSERV))
+            if (!xfer_network_resolve_addr (str_address, NULL,
+                                            (struct sockaddr*)&own_ip_addr,
+                                            &length,
+                                            AI_NUMERICSERV))
             {
                 goto error;
             }
@@ -1286,9 +1191,9 @@ xfer_add_cb (const void *pointer, void *data,
             /* no own_ip, so bind_addr's family comes from irc connection  */
             str_address = weechat_infolist_string (infolist, "local_address");
             length = sizeof (addr);
-            if (!xfer_resolve_addr (str_address, NULL,
-                                    (struct sockaddr*)&addr, &length,
-                                    AI_NUMERICSERV | AI_NUMERICHOST))
+            if (!xfer_network_resolve_addr (str_address, NULL,
+                                            (struct sockaddr*)&addr, &length,
+                                            AI_NUMERICSERV | AI_NUMERICHOST))
             {
                 goto error;
             }
@@ -1445,7 +1350,7 @@ xfer_add_cb (const void *pointer, void *data,
     if (short_filename)
         free (short_filename);
     weechat_infolist_reset_item_cursor (infolist);
-    return WEECHAT_RC_OK;
+    return WEECHAT_RC_OK_EAT;
 
 error:
     if (filename2)
@@ -1924,8 +1829,8 @@ weechat_plugin_end (struct t_weechat_plugin *plugin)
 
     if (xfer_signal_upgrade_received)
         xfer_upgrade_save ();
-    else
-        xfer_disconnect_all ();
+
+    xfer_disconnect_all ();
 
     xfer_free_all ();
 
