@@ -23,6 +23,8 @@ Unparse AST tree to generate scripts in all supported languages
 """
 
 # pylint: disable=too-many-lines,unnecessary-pass,useless-object-inheritance
+# pylint: disable=consider-using-f-string
+# pylint: disable=super-with-arguments
 
 from __future__ import print_function
 import argparse
@@ -74,7 +76,7 @@ class UnparsePython(object):
         }
         self.unaryop = {
             'Invert': '~',
-            'Not': 'not',
+            'Not': 'not ',
             'UAdd': '+',
             'USub': '-',
         }
@@ -255,6 +257,11 @@ class UnparsePython(object):
                 self.unindent,
             )
 
+    def _ast_index(self, node):
+        """Add an AST Subscript in output."""
+        # note: deprecated since Python 3.9
+        self.add(node.value)
+
     def _ast_import(self, node):
         """Add an AST Import in output."""
         # ignore import
@@ -287,7 +294,16 @@ class UnparsePython(object):
     def _ast_str(self, node):
         """Add an AST Str in output."""
         # note: deprecated since Python 3.8, replaced by ast.Constant
-        self.add(repr(node.s))
+        self._ast_constant(node)
+
+    def _ast_subscript(self, node):
+        """Add an AST Subscript in output."""
+        self.add(
+            node.value,
+            '[',
+            node.slice,
+            ']',
+        )
 
     def _ast_tuple(self, node):
         """Add an AST Tuple in output."""
@@ -301,11 +317,8 @@ class UnparsePython(object):
     def _ast_unaryop(self, node):
         """Add an AST UnaryOp in output."""
         self.add(
-            '(',
             self.unaryop[node.op.__class__.__name__],
-            ' ',
             node.operand,
-            ')',
         )
 
 
@@ -323,7 +336,7 @@ class UnparsePerl(UnparsePython):
         """Add an AST Assign in output."""
         self.add(
             self.fill,
-            (self.prefix, '%' if isinstance(node.value, ast.Dict) else '$'),
+            (self.prefix, '$'),
             [[target, ' = '] for target in node.targets],
             (self.prefix, None),
             node.value,
@@ -487,6 +500,17 @@ class UnparsePerl(UnparsePython):
         # note: deprecated since Python 3.8, replaced by ast.Constant
         self.add('"%s"' % node.s.replace('$', '\\$').replace('@', '\\@'))
 
+    def _ast_subscript(self, node):
+        """Add an AST Subscript in output."""
+        self.add(
+            (self.prefix, '$'),
+            node.value,
+            (self.prefix, None),
+            '->{',
+            node.slice,
+            '}',
+        )
+
 
 class UnparseRuby(UnparsePython):
     """
@@ -506,6 +530,13 @@ class UnparseRuby(UnparsePython):
             node.attr,
         )
 
+    def _ast_constant(self, node):
+        """Add an AST Constant in output."""
+        if isinstance(node.value, str):
+            self.add('"%s"' % node.s.replace('#{', '\\#{'))
+        else:
+            self.add(repr(node.s))
+
     def _ast_dict(self, node):
         """Add an AST Dict in output."""
         self.add(
@@ -673,14 +704,15 @@ class UnparseTcl(UnparsePython):
 
     def _ast_assign(self, node):
         """Add an AST Assign in output."""
+        exclude_types = (ast.Dict, ast.Str, ast.Subscript)
         self.add(
             self.fill,
             'set ',
             node.targets[0],
             ' ',
-            '[' if not isinstance(node.value, ast.Str) else '',
+            '[' if not isinstance(node.value, exclude_types) else '',
             node.value,
-            ']' if not isinstance(node.value, ast.Str) else '',
+            ']' if not isinstance(node.value, exclude_types) else '',
         )
 
     def _ast_attribute(self, node):
@@ -824,6 +856,18 @@ class UnparseTcl(UnparsePython):
         # note: deprecated since Python 3.8, replaced by ast.Constant
         self.add('"%s"' % node.s.replace('$', '\\$'))
 
+    def _ast_subscript(self, node):
+        """Add an AST Subscript in output."""
+        self.add(
+            '[dict get ',
+            (self.prefix, '$'),
+            node.value,
+            (self.prefix, None),
+            ' ',
+            node.slice,
+            ']',
+        )
+
 
 class UnparseGuile(UnparsePython):
     """
@@ -1010,6 +1054,16 @@ class UnparseGuile(UnparsePython):
         # note: deprecated since Python 3.8, replaced by ast.Constant
         self.add('"%s"' % node.s)
 
+    def _ast_subscript(self, node):
+        """Add an AST Subscript in output."""
+        self.add(
+            '(assoc-ref ',
+            node.value,
+            ' ',
+            node.slice,
+            ')',
+        )
+
 
 class UnparseJavascript(UnparsePython):
     """
@@ -1225,6 +1279,16 @@ class UnparsePhp(UnparsePython):
         # note: deprecated since Python 3.8, replaced by ast.Constant
         self.add('"%s"' % node.s.replace('$', '\\$'))
 
+    def _ast_subscript(self, node):
+        """Add an AST Subscript in output."""
+        self.add(
+            '$',
+            node.value,
+            '[',
+            node.slice,
+            ']',
+        )
+
 
 def get_languages():
     """Return a list of supported languages: ['python', 'perl', ...]."""
