@@ -85,6 +85,8 @@ IMPORT_TEST_GROUP(GuiBarWindow);
 IMPORT_TEST_GROUP(GuiBuffer);
 IMPORT_TEST_GROUP(GuiChat);
 IMPORT_TEST_GROUP(GuiColor);
+IMPORT_TEST_GROUP(GuiFilter);
+IMPORT_TEST_GROUP(GuiInput);
 IMPORT_TEST_GROUP(GuiLine);
 IMPORT_TEST_GROUP(GuiNick);
 /* scripts */
