@@ -931,6 +931,21 @@ TEST(CoreString, ConvertEscapedChars)
     WEE_TEST_STR("\\~zzy", string_convert_escaped_chars ("\\~zzy"));
 }
 
+/*
+ * Tests functions:
+ *   string_is_whitespace_char
+ */
+
+TEST(CoreString, IsWhitespaceChar)
+{
+    LONGS_EQUAL(0, string_is_whitespace_char (NULL));
+    LONGS_EQUAL(0, string_is_whitespace_char (""));
+    LONGS_EQUAL(0, string_is_whitespace_char ("abc def"));
+
+    LONGS_EQUAL(1, string_is_whitespace_char (" abc def"));
+    LONGS_EQUAL(1, string_is_whitespace_char ("\tabc def"));
+}
+
 /*
  * Tests functions:
  *   string_is_word_char_highlight
@@ -1700,15 +1715,15 @@ TEST(CoreString, SplitTags)
 
 /*
  * Tests functions:
- *    string_build_with_split_string
+ *    string_rebuild_split_string
  */
 
-TEST(CoreString, SplitBuildWithSplitString)
+TEST(CoreString, RebuildSplitString)
 {
     char **argv, *str;
     int argc, flags;
 
-    str = string_build_with_split_string (NULL, NULL);
+    str = string_rebuild_split_string (NULL, NULL, 0, -1);
     POINTERS_EQUAL(NULL, str);
 
     flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
@@ -1716,18 +1731,96 @@ TEST(CoreString, SplitBuildWithSplitString)
         | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS;
     argv = string_split (" abc de  fghi ", " ", NULL, flags, 0, &argc);
 
-    str = string_build_with_split_string ((const char **)argv, NULL);
+    /* invalid index_end, which is < index_start */
+    str = string_rebuild_split_string ((const char **)argv, NULL, 1, 0);
+    POINTERS_EQUAL(NULL, str);
+    str = string_rebuild_split_string ((const char **)argv, NULL, 2, 1);
+    POINTERS_EQUAL(NULL, str);
+
+    str = string_rebuild_split_string ((const char **)argv, NULL, 0, -1);
     STRCMP_EQUAL("abcdefghi", str);
     free (str);
 
-    str = string_build_with_split_string ((const char **)argv, "");
+    str = string_rebuild_split_string ((const char **)argv, NULL, 0, 0);
+    STRCMP_EQUAL("abc", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, NULL, 0, 1);
+    STRCMP_EQUAL("abcde", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, NULL, 0, 2);
     STRCMP_EQUAL("abcdefghi", str);
     free (str);
 
-    str = string_build_with_split_string ((const char **)argv, ";;");
+    str = string_rebuild_split_string ((const char **)argv, NULL, 0, 3);
+    STRCMP_EQUAL("abcdefghi", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, NULL, 1, 1);
+    STRCMP_EQUAL("de", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, NULL, 1, 2);
+    STRCMP_EQUAL("defghi", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, NULL, 1, 3);
+    STRCMP_EQUAL("defghi", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, NULL, 2, 2);
+    STRCMP_EQUAL("fghi", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, NULL, 2, 3);
+    STRCMP_EQUAL("fghi", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, "", 0, -1);
+    STRCMP_EQUAL("abcdefghi", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, ";;", 0, -1);
     STRCMP_EQUAL("abc;;de;;fghi", str);
     free (str);
 
+    str = string_rebuild_split_string ((const char **)argv, ";;", 0, 0);
+    STRCMP_EQUAL("abc", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, ";;", 0, 1);
+    STRCMP_EQUAL("abc;;de", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, ";;", 0, 2);
+    STRCMP_EQUAL("abc;;de;;fghi", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, ";;", 0, 3);
+    STRCMP_EQUAL("abc;;de;;fghi", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, ";;", 1, 1);
+    STRCMP_EQUAL("de", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, ";;", 1, 2);
+    STRCMP_EQUAL("de;;fghi", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, ";;", 1, 3);
+    STRCMP_EQUAL("de;;fghi", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, ";;", 2, 2);
+    STRCMP_EQUAL("fghi", str);
+    free (str);
+
+    str = string_rebuild_split_string ((const char **)argv, ";;", 2, 3);
+    STRCMP_EQUAL("fghi", str);
+    free (str);
+
     string_free_split (argv);
 }
 
@@ -1812,6 +1905,76 @@ TEST(CoreString, FormatSize)
     WEE_FORMAT_SIZE("42.00 TB", 42 * ONE_TB);
 }
 
+/*
+ * Tests functions:
+ *    string_parse_size
+ */
+
+TEST(CoreString, ParseSize)
+{
+    CHECK(string_parse_size (NULL) == 0ULL);
+
+    CHECK(string_parse_size ("") == 0ULL);
+    CHECK(string_parse_size ("*") == 0ULL);
+    CHECK(string_parse_size ("b") == 0ULL);
+    CHECK(string_parse_size ("k") == 0ULL);
+    CHECK(string_parse_size ("m") == 0ULL);
+    CHECK(string_parse_size ("g") == 0ULL);
+    CHECK(string_parse_size ("t") == 0ULL);
+    CHECK(string_parse_size ("z") == 0ULL);
+    CHECK(string_parse_size ("0z") == 0ULL);
+
+    CHECK(string_parse_size ("0") == 0ULL);
+    CHECK(string_parse_size ("0b") == 0ULL);
+    CHECK(string_parse_size ("0B") == 0ULL);
+
+    CHECK(string_parse_size ("1") == 1ULL);
+    CHECK(string_parse_size ("1b") == 1ULL);
+    CHECK(string_parse_size ("1B") == 1ULL);
+    CHECK(string_parse_size ("1 b") == 1ULL);
+    CHECK(string_parse_size ("1 B") == 1ULL);
+
+    CHECK(string_parse_size ("2") == 2ULL);
+    CHECK(string_parse_size ("2b") == 2ULL);
+    CHECK(string_parse_size ("2B") == 2ULL);
+
+    CHECK(string_parse_size ("42") == 42ULL);
+    CHECK(string_parse_size ("42b") == 42ULL);
+    CHECK(string_parse_size ("42B") == 42ULL);
+
+    CHECK(string_parse_size ("999") == 999ULL);
+    CHECK(string_parse_size ("999b") == 999ULL);
+    CHECK(string_parse_size ("999B") == 999ULL);
+
+    CHECK(string_parse_size ("1200") == 1200ULL);
+    CHECK(string_parse_size ("1200b") == 1200ULL);
+    CHECK(string_parse_size ("1200B") == 1200ULL);
+
+    CHECK(string_parse_size ("1k") == 1000ULL);
+    CHECK(string_parse_size ("1K") == 1000ULL);
+
+    CHECK(string_parse_size ("12k") == 12000ULL);
+    CHECK(string_parse_size ("12K") == 12000ULL);
+
+    CHECK(string_parse_size ("1m") == 1000000ULL);
+    CHECK(string_parse_size ("1M") == 1000000ULL);
+
+    CHECK(string_parse_size ("30m") == 30000000ULL);
+    CHECK(string_parse_size ("30M") == 30000000ULL);
+
+    CHECK(string_parse_size ("1g") == 1000000000ULL);
+    CHECK(string_parse_size ("1G") == 1000000000ULL);
+
+    CHECK(string_parse_size ("1234m") == 1234000000ULL);
+    CHECK(string_parse_size ("1234m") == 1234000000ULL);
+
+    CHECK(string_parse_size ("15g") == 15000000000ULL);
+    CHECK(string_parse_size ("15G") == 15000000000ULL);
+
+    CHECK(string_parse_size ("8t") == 8000000000000ULL);
+    CHECK(string_parse_size ("8T") == 8000000000000ULL);
+}
+
 /*
  * Tests functions:
  *    string_base16_encode
@@ -2387,4 +2550,23 @@ TEST(CoreString, Dyn)
     STRCMP_EQUAL("abcdxxyxyz", str_ptr);
 
     free (str_ptr);
+
+    str_ptr = NULL;
+    str = &str_ptr;
+
+    /* test copy to NULL */
+    LONGS_EQUAL(0, string_dyn_copy (NULL, NULL));
+    LONGS_EQUAL(0, string_dyn_copy (NULL, "a"));
+    LONGS_EQUAL(0, string_dyn_copy (str, NULL));
+    LONGS_EQUAL(0, string_dyn_copy (str, "a"));
+
+    /* test concat to NULL */
+    LONGS_EQUAL(0, string_dyn_concat (NULL, NULL, 1));
+    LONGS_EQUAL(0, string_dyn_concat (NULL, "a", 1));
+    LONGS_EQUAL(0, string_dyn_concat (str, NULL, 1));
+    LONGS_EQUAL(0, string_dyn_concat (str, "a", 1));
+
+    /* test free of NULL */
+    string_dyn_free (NULL, 0);
+    string_dyn_free (str, 0);
 }
